# mypy-boto3-lambda

[![PyPI - mypy-boto3-lambda](https://img.shields.io/pypi/v/mypy-boto3-lambda.svg?color=blue)](https://pypi.org/project/mypy-boto3-lambda)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-lambda.svg?color=blue)](https://pypi.org/project/mypy-boto3-lambda)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

- [mypy-boto3-lambda](#mypy-boto3-lambda)
  - [How to use](#how-to-use)
  - [Automated type discovery](#automated-type-discovery)


Type annotations for
[boto3.Lambda 1.13.26](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/lambda.html#Lambda) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.0.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-lambda](#mypy-boto3-lambda)
  - [How to use](#how-to-use)
    - [Type checking](#type-checking)
  - [How it works](#how-it-works)

## How to use

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `Lambda` service.

```bash
python -m pip install boto3-stubs[lambda]

# update installed packages index for automated type discovery
python -m mypy_boto3
```

Use `boto3` with `mypy_boto3_lambda` in your project and enjoy type checking and auto-complete.

```python
import boto3

from mypy_boto3_lambda import LambdaClient

# Now mypy can check if your code is valid.
client: LambdaClient = boto3.client("lambda")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: LambdaClient = session.client("lambda")



# Waiters are also supported

import mypy_boto3_lambda.waiter as lambda_waiters

function_active_waiter: lambda_waiters.FunctionActiveWaiter = client.get_waiter("function_active")
function_exists_waiter: lambda_waiters.FunctionExistsWaiter = client.get_waiter("function_exists")
function_updated_waiter: lambda_waiters.FunctionUpdatedWaiter = client.get_waiter("function_updated")


# Annotated paginators are included as well

import mypy_boto3_lambda.paginator as lambda_paginators

list_aliases_paginator: lambda_paginators.ListAliasesPaginator = client.get_paginator("list_aliases")
list_event_source_mappings_paginator: lambda_paginators.ListEventSourceMappingsPaginator = client.get_paginator("list_event_source_mappings")
list_function_event_invoke_configs_paginator: lambda_paginators.ListFunctionEventInvokeConfigsPaginator = client.get_paginator("list_function_event_invoke_configs")
list_functions_paginator: lambda_paginators.ListFunctionsPaginator = client.get_paginator("list_functions")
list_layer_versions_paginator: lambda_paginators.ListLayerVersionsPaginator = client.get_paginator("list_layer_versions")
list_layers_paginator: lambda_paginators.ListLayersPaginator = client.get_paginator("list_layers")
list_provisioned_concurrency_configs_paginator: lambda_paginators.ListProvisionedConcurrencyConfigsPaginator = client.get_paginator("list_provisioned_concurrency_configs")
list_versions_by_function_paginator: lambda_paginators.ListVersionsByFunctionPaginator = client.get_paginator("list_versions_by_function")
```

## Automated type discovery

`mypy_boto3` package can generate index for `mypy_boto3_lambda` and other installed services.

```bash
# Run this command when you add or remove service packages
python -m mypy_boto3
```

Generated index provides overloads for `boto3.client` and `boto3.service`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully
- `VSCode` does not currently support function overloads

Also, generated index allows you to import types from `mypy_boto3`:

```python
# you can replace imports
import mypy_boto3_lambda as lambda_
from mypy_boto3_lambda import LambdaClient

# with these
from mypy_boto3 import lambda_
from mypy_boto3.lambda_ import LambdaClient
```